#!/bin/bash

PLATFORM_ID='-VSTL'
OAD_IMG="mb70_oad.img"
####################

#Determine MTD locations (should be static, but doesn't hurt to handle this dynamically)
ROOTFS0_BLOCK=$(grep '"rootfs0"' /proc/mtd | cut -d':' -f 1)
ROOTFS1_BLOCK=$(grep '"rootfs1"' /proc/mtd | cut -d':' -f 1)
KERNEL_BLOCK=$(grep '"kernel"' /proc/mtd | cut -d':' -f 1)
KERNEL_INITRD_BLOCK=$(grep '"initrd"' /proc/mtd | cut -d':' -f 1)
DB_BLOCK=$(grep '"db"' /proc/mtd | cut -d':' -f 1)
DB_BACKUP_BLOCK=$(grep '"db_backup"' /proc/mtd | cut -d':' -f 1)
SPLASH_BLOCK=$(grep '"splash"' /proc/mtd | cut -d':' -f 1)
SETTINGS_BLOCK=$(grep '"settings"' /proc/mtd  | cut -d ':' -f 1)
YAHOO_BLOCK=$(grep '"yahoo"' /proc/mtd  | cut -d ':' -f 1)
YAHOO_DATA_BLOCK=$(grep '"yahoo_data"' /proc/mtd  | cut -d ':' -f 1)
DISCRETIX_DRM_BLOCK=$(grep '"spare0"' /proc/mtd  | cut -d ':' -f 1)

####################
#
# Now start the update
#

echo -e "\n\nSTARTING UPDATE"

####################
#
# Image-based updates
#
if [ -f vmlinuz${PLATFORM_ID} ]
then
    echo -e "\nUpdating Kernel [$KERNEL_BLOCK]"
    eraseall -q /dev/$KERNEL_BLOCK
    nandwrite -pq /dev/$KERNEL_BLOCK vmlinuz${PLATFORM_ID}
    echo -e "Kernel update complete\n"
else
    echo -e "\n\"vmlinuz${PLATFORM_ID}\" not found - kernel will not be updated\n\n"
fi

if [ -f vmlinuz-initrd${PLATFORM_ID} ]
then
    echo -e "\nUpdating Kernel Initrd [$KERNEL_INITRD_BLOCK]"
    eraseall -q /dev/$KERNEL_INITRD_BLOCK
    nandwrite -pq /dev/$KERNEL_INITRD_BLOCK vmlinuz-initrd${PLATFORM_ID}
    echo -e "Kernel initrd update complete\n"
else
    echo -e "\n\"vmlinuz-initrd${PLATFORM_ID}\" not found - kernel will not be updated\n\n"
fi

if [ -f squashfs.img ]
then
    echo -e "\nUpdating RootFS [$ROOTFS0_BLOCK]"
    eraseall -q /dev/$ROOTFS0_BLOCK
    nandwrite -pq /dev/$ROOTFS0_BLOCK squashfs.img
    echo -e "RootFS update complete with squashfs file sytem\n"
elif [ -f cramfs.img ]
then
    echo -e "\nUpdating RootFS [$ROOTFS0_BLOCK]"
    eraseall -q /dev/$ROOTFS0_BLOCK
    nandwrite -pq /dev/$ROOTFS0_BLOCK cramfs.img
    echo -e "RootFS update complete with cramfs file system\n"
elif [ -f jffs2.img ]
then
    echo -e "\nUpdating RootFS [$ROOTFS0_BLOCK]"
    eraseall -q /dev/$ROOTFS0_BLOCK
    nandwrite -pq /dev/$ROOTFS0_BLOCK jffs2.img
    echo -e "RootFS update complete with jffs2 file sytem\n"    
else
    echo -e "\nRootFS will not be updated\n"
fi

if [ -f default_settings.img ]
then
    echo -e "\nUpdating Settings [$SETTINGS_BLOCK]"
    eraseall -q /dev/$SETTINGS_BLOCK
    nandwrite -pq /dev/$SETTINGS_BLOCK default_settings.img
    echo -e "Settings update complete\n"
else
    echo -e "\n\"default_settings.img\" not found - settings will not be updated\n"
fi

if [ -f splash.img ]
then
    echo -e "\nUpdating Splash [$SPLASH_BLOCK]"
    eraseall -q /dev/$SPLASH_BLOCK
    nandwrite -pq /dev/$SPLASH_BLOCK splash.img
    echo -e "Splash update complete\n"
else
    echo -e "\nSplash will not be updated\n"
fi

if [ -f yahoo.img ]
then
    echo -e "\nUpdating Yahoo! [$YAHOO_BLOCK]"
    eraseall -q /dev/$YAHOO_BLOCK
    nandwrite -pq /dev/$YAHOO_BLOCK yahoo.img
    echo -e "Yahoo! update complete\n"
fi

if [ -f yahoo.img ]
then
    echo -e "\nChecking Yahoo Data! [$YAHOO_DATA_BLOCK]"
    mount -t jffs2 /dev/${YAHOO_BLOCK:3} /mnt/yahoo_data > /dev/null
    if [ $? -ne 0 ]
    then
        echo -e "Erasing Yahoo Data!\n"
        eraseall -q /dev/$YAHOO_DATA_BLOCK
    else
        umount /mnt/yahoo_data
    fi
    sync
fi

if [ -f discretix_drm_data.img ]
then
    echo -e "\nUpdating Discretix DRM Data! [$DISCRETIX_DRM_BLOCK]"
    eraseall -q /dev/$DISCRETIX_DRM_BLOCK
    nandwrite -pq /dev/$DISCRETIX_DRM_BLOCK discretix_drm_data.img
    echo -e "Discretix DRM Data update complete\n"
else
    echo -e "\nDiscretix DRM Data will not be updated\n"
fi

echo -e "\n[$ROOTFS1_BLOCK] : erase all...\n"
eraseall -q /dev/$ROOTFS1_BLOCK

sleep 1

mkdir /mnt/tmp
mkdir /mnt/tmp_db
mkdir /mnt/tmp_db_backup
mount -t tmpfs -o size='10m' /dev/null /mnt/tmp
mount -t jffs2 /dev/mtdblock${DB_BLOCK:3} /mnt/tmp_db > /dev/null
if [ $? -eq 0 ]
then
    if [ -f /mnt/tmp_db/nvblock_0.bin ]
    then
        echo -e "\nCopy database files to tmpfs.\n"
        cp -rf /mnt/tmp_db/nvblock_*.bin /mnt/tmp
    fi
fi
sync
umount -l /mnt/tmp_db > /dev/null
sleep 1
echo -e "\n[$DB_BLOCK] : erase all...\n"
eraseall -q /dev/$DB_BLOCK

mount -t jffs2 /dev/mtdblock${DB_BACKUP_BLOCK:3} /mnt/tmp_db_backup > /dev/null
if [ $? -eq 0 ]
then
    if [ -f /mnt/tmp_db_backup/nvblock_0.bin.gz ]
    then
        echo -e "\nCopy database backup files to tmpfs.\n"
        cp -rf /mnt/tmp_db_backup/nvblock_*.gz /mnt/tmp    
    fi
fi    
sync
umount -l /mnt/tmp_db_backup > /dev/null
sleep 1
echo -e "\n[$DB_BACKUP_BLOCK] : erase all...\n"
eraseall -q /dev/$DB_BACKUP_BLOCK

mount -t jffs2 /dev/mtdblock${DB_BLOCK:3} /mnt/tmp_db > /dev/null
if [ $? -eq 0 ]
then
    if [ -f /mnt/tmp/nvblock_0.bin ]
    then
        echo -e "\nCopy tmpfs db files to [$DB_BLOCK]\n"
        cp -rf /mnt/tmp/nvblock_*.bin /mnt/tmp_db
    elif [ -f /mnt/tmp/nvblock_0.bin.gz ]
    then
        echo -e "\nUnzip db backup files to [$DB_BLOCK]\n"
        cp -rf /mnt/tmp/nvblock_*.gz /mnt/tmp_db
        cd /mnt/tmp_db
        gunzip -f *.gz
        cd -            
    fi
fi
sync
umount -l /mnt/tmp_db > /dev/null

mount -t jffs2 /dev/mtdblock${DB_BACKUP_BLOCK:3} /mnt/tmp_db_backup > /dev/null
if [ $? -eq 0 ]
then
    if [ -f /mnt/tmp/nvblock_0.bin.gz ]
    then
        echo -e "\nCopy tmpfs db backup files to [$DB_BACKUP_BLOCK]\n"
        cp -rf /mnt/tmp/nvblock_*.gz /mnt/tmp_db_backup
    fi
fi
sync
umount -l /mnt/tmp_db_backup > /dev/null

umount -l /mnt/tmp > /dev/null

sleep 1

####################
#
# File-based updates
mount -t jffs2 /dev/mtdblock${SETTINGS_BLOCK:3} /mnt/nfs > /dev/null
if [ $? -eq 0 ]
then
    ########## profile ##########
    if [ ! -d /mnt/nfs/profile ]
    then
        echo -e "\n\nprofile mount point does not exist: will create it.\n\n"
        mkdir /mnt/nfs/profile
    fi
    
    if [ -f toros_hwprofile.bin ]
    then
        echo -e "\nCopy toros_hwprofile.bin to profile.\n"
        cp toros_hwprofile.bin /mnt/nfs/profile
    fi
    
    if [ -f toros_swprofile.bin ]
    then
        echo -e "\nCopy toros_swprofile.bin to profile.\n"
        cp toros_swprofile.bin /mnt/nfs/profile
    fi 

    ########## edid ##########
    if [ -f edid.bin ]
    then
        echo -e "\nCopy edid.bin to edid_data.\n"
        cp edid.bin /mnt/nfs/edid_data
    fi
    
    ########## preset services ##########
    if [ ! -d /mnt/nfs/preset_services ]
    then
        echo -e "\n\npreset services mount point does not exist: will create it.\n\n"
        mkdir /mnt/nfs/preset_services
    fi

    if [ -f default_preset_services.sdx ]
    then
        echo -e "\nCopy preset channels to preset_services.\n"
        cp default_preset_services.sdx /mnt/nfs/preset_services
        rm -f /mnt/nfs/preset_services/default_preset_services.inf
    fi

    ########## pnx files ##########
    if [ ! -d /mnt/nfs/pnx_config ]
    then
        echo -e "\n\npnx_config mount point does not exist: will create it.\n\n"
        mkdir /mnt/nfs/pnx_config
    fi

    if [ -f pnx51xx_default.pnsp ]
    then
        echo -e "\nCopy pnx51xx_default.pnsp\n"
        cp pnx51xx_default.pnsp /mnt/nfs/pnx_config
    fi

    if [ -f pnx51xx_default.pqfp ]
    then
        echo -e "\nCopy pnx51xx_default.pqfp\n"
        cp pnx51xx_default.pqfp /mnt/nfs/pnx_config
    fi

    if [ -f pnx51xx_default.pqsp ]
    then
        echo -e "\nCopy pnx51xx_default.pqsp\n"
        cp pnx51xx_default.pqsp /mnt/nfs/pnx_config
    fi

    ########## pix files ##########
    if [ ! -d /mnt/nfs/pix_config ]
    then
        echo -e "\n\npix_config mount point does not exist: will create it.\n\n"
        mkdir /mnt/nfs/pix_config
    fi

    if [ -f pix_configurations.pix ]
    then
        echo -e "\nCopy pix_configurations.pix\n"
        cp pix_configurations.pix /mnt/nfs/pix_config
    fi

    if [ -f pix_dcelevels.pix ]
    then
        echo -e "\nCopy pix_dcelevels.pix\n"
        cp pix_dcelevels.pix /mnt/nfs/pix_config
    fi

    if [ -f pix_gamma.pix ]
    then
        echo -e "\nCopy pix_gamma.pix\n"
        cp pix_gamma.pix /mnt/nfs/pix_config
    fi

    if [ -f pix_profiles.pix ]
    then
        echo -e "\nCopy pix_profiles.pix\n"
        cp pix_profiles.pix /mnt/nfs/pix_config
    fi

    if [ -f pix_skintone.pix ]
    then
        echo -e "\nCopy pix_skintone.pix\n"
        cp pix_skintone.pix /mnt/nfs/pix_config
    fi

    if [ -f pix_sources.pix ]
    then
        echo -e "\nCopy pix_sources.pix\n"
        cp pix_sources.pix /mnt/nfs/pix_config
    fi
    
    ########## tuning_data ##########
    if [ ! -d /mnt/nfs/tune ]
    then
        echo -e "\n\ntuning_data mount point does not exist: will create it.\n\n"
        mkdir /mnt/nfs/tune
    fi    

    if [ -f bti_a.dat ]
    then
        echo -e "\nCopy bti_a.dat to tuning_data.\n"
        cp bti_a.dat /mnt/nfs/tune
    fi

    if [ -f bti_p.dat ]
    then
        echo -e "\nCopy bti_p.dat to tuning_data.\n"
        cp bti_p.dat /mnt/nfs/tune
    fi
    
    if [ -f bti_v.dat ]
    then
        echo -e "\nCopy bti_v.dat to tuning_data.\n"
        cp bti_v.dat /mnt/nfs/tune
    fi    

    ########## iplayer certificates ##########
    if [ -f vestel_key.p12 ]
    then
        echo -e "\nCopy vestel_key.p12 for iplayer.\n"
        cp vestel_key.p12 /mnt/nfs/browser/iplayer_client_cert
    fi 

    if [ -f iplayer_client.inf ]
    then
        echo -e "\nCopy iplayer_client.inf for iplayer.\n"
        cp iplayer_client.inf /mnt/nfs/browser/iplayer_client_cert
    fi 

    ##################################
    #########   remove fast turn on data file ######## 
    if [ -f /mnt/nfs/fastTurnOn.bin ]
    then
        echo -e "\nRemove FastTurnOn data file.\n"
        rm -f /mnt/nfs/fastTurnOn.bin
    fi
fi

########## portal startup URL ##########
if [ -f starturl.txt ]
then
    echo -e "\nPreparing to update Portal starting url..\n"
    cp -f /mnt/hd/starturl.txt /mnt/nfs/browser
fi

########## Boot Up Picture ##########
if [ -f BootIFrame.data ]
then
    echo -e "\nUpdating boot Iframe..\n"
    cp -f /mnt/hd/BootIFrame.data /mnt/nfs/bootup_picture
fi

########## PRODUCTION CREDENTIALS##########
if [ -f PRODUCTION_CREDENTIALS.bin ]
then
    echo -e "\nUpdating PRODUCTION CREDENTIALS..\n"
    cp -f /mnt/hd/PRODUCTION_CREDENTIALS.bin /mnt/nfs/ciplus_credentials
fi

umount -l /mnt/nfs > /dev/null

sync    # Flush filesystem just to be sure

echo -e "\n\nUPDATE COMPLETE\nPlease remove the usb device and reset your TV\n\n"

